def read_arguments():
    """
    Parse and return the command-line arguments for input and output file paths.

    This function defines the command-line arguments for processing input files and the output file/directory,
    and then parses these arguments to extract their values.

    Returns
    -------
    tuple of str
        A tuple containing:
        - input_path_1 (str): The path of the first input file.
        - input_path_2 (str): The path of the second input file.
        - output_path (str): The path of the output directory.
        - output_name (str or None): The name of the output file (optional).

    Examples
    --------
    >>> input_path_1, input_path_2, output_path, output_name = read_arguments()
    """
    parser = argparse.ArgumentParser(description='Process_files')

    # Define the inputs (-i and -g) and the output (-o)
    parser.add_argument("-i", "--input1", "input_path_1", type=str, required=True,
                        help="The path of the first input file")
    parser.add_argument("-g", "--input2", "input_path_2", type=str, required=True,
                        help="The path of the second input file")
    parser.add_argument("-o", "--output", "output_path", type=str, required=True,
                        help="The path of the output directory")
    parser.add_argument("-n", "--doc_name", type=str, required=False, help="The name of the output file (optional)")

    args = parser.parse_args()

    # Assign the inputs and output to different variables
    input_path_1 = args.input1
    input_path_2 = args.input2
    output_path = args.output
    output_name = args.doc_name

    return input_path_1, input_path_2, output_path, output_name
